{pkgs, ...}: {
  programs.firefox = {
    enable = true;
    profiles = {
      "aria" = {
        extensions = with pkgs.nur.repos.rycee.firefox-addons; [
          ublock-origin
          bitwarden
          canvasblocker
          aria2-integration
          sponsorblock
          xbrowsersync
        ];
        settings = {
          "browser.aboutConfig.showWarning" = false;
          "browser.startup.page" = 1;
          "geo.provider.network.url" = "https://location.services.mozilla.com/v1/geolocate?key=%MOZILLA_API_KEY%";
          "intl.accept_languages" = "en-US, en";
          "app.update.auto" = false;
          "browser.download.useDownloadDir" = false;
          "browser.download.manager.addToRecentDocs" = false;
          "extensions.pocket.enabled" = false;
        };
        search = {
          default = "Ecosia";
          engines = {
            "Nix Packages" = {
              urls = [
                {
                  template = "https://search.nixos.org/packages";
                  params = [
                    {
                      name = "type";
                      value = "packages";
                    }
                    {
                      name = "query";
                      value = "{searchTerms}";
                    }
                  ];
                }
              ];
              icon = "${pkgs.nixos-icons}/share/icons/hicolor/scalable/apps/nix-snowflake.svg";
              definedAliases = ["@np"];
            };
            "Celtic Lite" = {
              urls = [
                {
                  template = "https://search.celticlite.com/search";
                  params = [
                    {
                      name = "query";
                      value = "{searchTerms}";
                    }
                  ];
                }
              ];
              definedAliases = ["@cl"];
            };
            "Google".metaData.hidden = true;
            "Amazon.com".metaData.hidden = true;
            "Bing".metaData.hidden = true;
            "eBay".metaData.hidden = true;
          };
        };
      };
    };
  };
}
